# estimagic (renamed to optimagic)

The project has been renamed to optimagic. The new repository is at
https://github.com/optimagic-dev/optimagic/. This repository is used temporarily to
release optimagic under the name estimagic.
